@@ -4,8 +4,7 @@
 
 import pytest
 
-
-from aiolip import aiolip
+from aiolip import LIP
 
 
 @pytest.fixture
@@ -18,7 +17,6 @@ def response():
     # return requests.get('https://github.com/audreyr/cookiecutter-pypackage')
 
 
-def test_content(response):
-    """Sample pytest test function with the pytest fixture as an argument."""
-    # from bs4 import BeautifulSoup
-    # assert 'GitHub' in BeautifulSoup(response.content).title.string
+def test_create(response):
+    """Test to create the object."""
+    LIP()
